******************************************************************************
*                                                                            *
*   PROGRAM: cage                                                            *
*                                                                            *
*   PURPOSE: Create Awas geometry input data file for a wire cage            *
*                                                                            *
******************************************************************************

	program cage

c	the cage is placed on top of a perfectly conducting ground plane (Oxy plane)

	implicit none
	real a,b,h,r,x,y,z
	integer na,nb,nh,nn,ns,i,j,nodea,nodeb

c	get input data from the default input device (keyboard)
c	numbers are entered in a free format

c	a - cage length (along x-axis)
c	b - cage width (along y-axis)
c	h - cage height (along z-axis)
c	these dimensions are input in meters

	print 101
101	format(' Dimensions a,b,h (m)? ',$)
	read(*,*)a,b,h

c	na - number of eyelets along a
c	nb - number of eyelets along b
c	nh - number of eyelets along h

	print 102
102	format(' Numbers of eyelets per a,b,h? ',$)
	read(*,*)na,nb,nh

c	r - wire radius
c	this dimension is input in millimeters

	print 103
103	format(' Wire radius (mm)? ',$)
	read(*,*)r
	r=.001*r

c	end of input

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

c	open file cage.geo

	open (unit=1,file='cage.geo')

c	write title

	write(1,201)'                            Wire shielding cage'//
     1	'                             '
	write(1,201)' '
	write(1,201)' '
201	format(a76)

c	write operating mode code (scatterer, bistatic scattering)

	write(1,*)-3

c	write ground plane code (ground plane present)

	write(1,*)1

c	calculate numbers of nodes and segments
c	nn - number of nodes
c	ns - number of segments

	nn=(na+1)*(nb+1)+2*(na+nb)*nh
	ns=na*(nb+1)+(na+1)*nb+2*(na+nb)*(2*nh-1)

c	write number of nodes

	write(1,*)nn

c	write number of segments

	write(1,*)ns

c	write number of ports (no ports, the structure is a scatterer)

	write(1,*)0

c	write a blank line (optional)

	write(1,*)

c	define nodes for the cage roof

	do i=0,na
	  x=-0.5*a+i*a/na
	  do j=0,nb
	    y=-0.5*b+j*b/nb

c	write node coordinates (x,y,z)

	    write(1,*)x,y,h
	  end do
	end do

c	define nodes for the cage walls

	do i=0,nh-1
	  z=i*h/nh
	  do j=0,na-1
	    x=-0.5*a+j*a/na

c	write node coordinates (x,y,z)

	    write(1,*)x,-0.5*b,z
	  end do
	  do j=0,nb-1
	    y=-0.5*b+j*b/nb
	    write(1,*)0.5*a,y,z
	  end do
	  do j=na,1,-1
	    x=-0.5*a+j*a/na

c	write node coordinates (x,y,z)

	    write(1,*)x,0.5*b,z
	  end do
	  do j=nb,1,-1
	    y=-0.5*b+j*b/nb

c	write node coordinates (x,y,z)

	    write(1,*)-0.5*a,y,z
	  end do
	end do

c	write a blank line (optional)

	write(1,*)

c	define segments for the cage roof (parallel to y-axis)

	nodea=0
	do i=0,na
	  do j=1,nb
	    nodea=nodea+1
	    nodeb=nodea+1

c	write segment data
c	nodea - origin node
c	nodeb - terminal node
c	r - wire radius
c	all three complex impedances are 0 and the wire conductivity is 56 MS/m

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	  end do
	  nodea=nodea+1
	end do

c	define segments for the cage roof (parallel to x-axis)

	nodea=0
	do i=1,na
	  do j=0,nb
	    nodea=nodea+1
	    nodeb=nodea+nb+1

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	  end do
	end do

c	define segments for the cage walls (layer by layer)

	do i=1,nh-1
	  nodea=nodeb
	  do j=1,2*(na+nb)
	    nodea=nodea+1
	    nodeb=nodea+2*(na+nb)

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	  end do
	  do j=1,2*(na+nb)-1
	    nodea=nodea+1
	    nodeb=nodea+1

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	  end do
	  nodea=nodea+1
	  nodeb=nodea-2*(na+nb)+1

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	  nodeb=nodeb-1
	end do

c	define segments for the cage wall (connected to the roof)

	nodea=nodeb
	nodeb=-nb
	do i=1,na
	  nodea=nodea+1
	  nodeb=nodeb+nb+1

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	end do
	nodeb=nodeb+nb
	do i=1,nb
	  nodea=nodea+1
	  nodeb=nodeb+1

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	end do
	nodeb=nodeb+nb+2
	do i=1,na
	  nodea=nodea+1
	  nodeb=nodeb-nb-1

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	end do
	nodeb=nodeb-nb
	do i=1,nb
	  nodea=nodea+1
	  nodeb=nodeb-1

c	write segment data

	    write(1,*)
     1	nodea,nodeb,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'

	end do

c	no data for ports are written, as the number of ports is 0

c	close file cage.geo

	close(1)

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

c	terminate program

	end